==> xmule-1.9.0.tar.bz2: xmule-1.9.0/src/PPgGeneral.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef PPGGEN_H
#define PPGGEN_H

#include "Preferences.h"                // Needed for CPreferences
#include "wx/panel.h"                   // Needed for wxPanel
#include "wx/combobox.h"                // Needed for wxComboBox

class CPPgGeneral : public wxPanel
{
  //DECLARE_DYNAMIC(CPPgGeneral)
  DECLARE_DYNAMIC_CLASS(CPPgGeneral)
    CPPgGeneral() {};

public:
	CPPgGeneral(wxWindow* parent);
	virtual ~CPPgGeneral();

	void SetPrefs(CPreferences* in_prefs) {	app_prefs = in_prefs; }

// Dialog Data
	enum
        {
            IDD_PPG_GENERAL,
            IDD = IDD_PPG_GENERAL
        };
protected:
	CPreferences *app_prefs;
protected:
	//virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support

	//DECLARE_MESSAGE_MAP()
	void OnHScroll(wxScrollEvent& evt);
	DECLARE_EVENT_TABLE()
public:
	//virtual BOOL OnInitDialog();
 public:
	void LoadSettings(void);
public:
	void OnApply();
#if 0
	virtual BOOL OnApply();
	afx_msg void OnEnChangeNick()					{ SetModified(); }
	afx_msg void OnCbnSelchangeLangs()				{ SetModified(); }
	afx_msg void OnBnClickedFlat()					{ SetModified(); }
	afx_msg void OnBnClickedMintray()				{ SetModified(); }
	afx_msg void OnBnClickedBeeper()				{ SetModified(); }
	afx_msg void OnBnClickedExit()					{ SetModified(); }
	afx_msg void OnBnClickedSplashon()				{ SetModified(); }
	afx_msg void OnBnClickedDblclick()				{ SetModified(); }
	afx_msg void OnBnClickedBringtoforeground()		{ SetModified(); }
	afx_msg void OnBnClickedNotify()				{ SetModified(); }
	afx_msg void OnEnChangeTooltipdelay()			{ SetModified(); }
	afx_msg void OnBnClickedOnlinesig()				{ SetModified(); }
	afx_msg void OnBnClickedEd2kfix();
#endif
	void OnDesktopmode(wxEvent& evt);
protected:
	wxComboBox m_language;
public:
	void Localize(void);
};


#endif

==> xmule-1.9.1b.tar.bz2: xmule-1.9.1b/src/PPgGeneral.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef PPGGEN_H
#define PPGGEN_H

#include <wx/panel.h>                       // Needed for wxPanel

class CPreferences;

class CPPgGeneral : public wxPanel
{
  DECLARE_DYNAMIC_CLASS(CPPgGeneral)
    CPPgGeneral() {};

public:
	CPPgGeneral(wxWindow* parent);
	virtual ~CPPgGeneral();

	void SetPrefs(CPreferences* in_prefs) {	app_prefs = in_prefs; }

// Dialog Data
	enum
        {
            IDD_PPG_GENERAL,
            IDD = IDD_PPG_GENERAL
        };
protected:
	CPreferences *app_prefs;
protected:
	void OnHScroll(wxScrollEvent& evt);
	DECLARE_EVENT_TABLE()
 public:
	void LoadSettings(void);
public:
	void OnApply();
	void OnDesktopmode(wxCommandEvent& evt);
public:
	void Localize(void);
};

#endif
